==> plantuml-libs-5.2.0.tgz: package/distribution/homecloud-2/Hardware/Smartphone.md <==
# Smartphone


```text
homecloud-2/Hardware/Smartphone
```

```text
include('homecloud-2/Hardware/Smartphone')
```



| Illustration | Smartphone | SmartphoneCard | SmartphoneGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../homecloud-2/Hardware/Smartphone.png) | ![illustration for Smartphone](../../homecloud-2/Hardware/Smartphone.Local.png) | ![illustration for SmartphoneCard](../../homecloud-2/Hardware/SmartphoneCard.Local.png) | ![illustration for SmartphoneGroup](../../homecloud-2/Hardware/SmartphoneGroup.Local.png) |




## Smartphone

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element Smartphone
include('homecloud-2/Hardware/Smartphone')

' renders the element
Smartphone('Smartphone', 'Smartphone', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element Smartphone
include('homecloud-2/Hardware/Smartphone')

' renders the element
Smartphone('Smartphone', 'Smartphone', 'an optional tech label')
@enduml
```

## SmartphoneCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneCard
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneCard('SmartphoneCard', 'Smartphone Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneCard
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneCard('SmartphoneCard', 'Smartphone Card', 'an optional description')
@enduml
```

## SmartphoneGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneGroup
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneGroup('SmartphoneGroup', 'Smartphone Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneGroup
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneGroup('SmartphoneGroup', 'Smartphone Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/homecloud-2/Hardware/Smartphone.md <==
# Smartphone


```text
homecloud-2/Hardware/Smartphone
```

```text
include('homecloud-2/Hardware/Smartphone')
```



| Illustration | Smartphone | SmartphoneCard | SmartphoneGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../homecloud-2/Hardware/Smartphone.png) | ![illustration for Smartphone](../../homecloud-2/Hardware/Smartphone.Local.png) | ![illustration for SmartphoneCard](../../homecloud-2/Hardware/SmartphoneCard.Local.png) | ![illustration for SmartphoneGroup](../../homecloud-2/Hardware/SmartphoneGroup.Local.png) |




## Smartphone

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element Smartphone
include('homecloud-2/Hardware/Smartphone')

' renders the element
Smartphone('Smartphone', 'Smartphone', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element Smartphone
include('homecloud-2/Hardware/Smartphone')

' renders the element
Smartphone('Smartphone', 'Smartphone', 'an optional tech label')
@enduml
```

## SmartphoneCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneCard
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneCard('SmartphoneCard', 'Smartphone Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneCard
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneCard('SmartphoneCard', 'Smartphone Card', 'an optional description')
@enduml
```

## SmartphoneGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneGroup
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneGroup('SmartphoneGroup', 'Smartphone Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('homecloud-2/bootstrap')

' loads the Item which embeds the element SmartphoneGroup
include('homecloud-2/Hardware/Smartphone')

' renders the element
SmartphoneGroup('SmartphoneGroup', 'Smartphone Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
